==> java-client-5.0.4-sources.jar: io/appium/java_client/FindsByFluentSelector.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.appium.java_client;

import org.openqa.selenium.WebElement;

import java.util.List;

public interface FindsByFluentSelector<T extends WebElement> {

    /**
    * Method performs the searching for a single element by some selector defined by string
    * and value of the given selector
    *
    * @param by is a string selector
    * @param using is a value of the given selector
    * @return the first found element
    *
    * @throws org.openqa.selenium.WebDriverException when current session doesn't
    *       support the given selector or when value of the selector is not consistent.
    * @throws org.openqa.selenium.NoSuchElementException when no one element is found
    */
    T findElement(String by, String using);

    /**
    * Method performs the searching for a list of elements by some selector defined by string
    * and value of the given selector
    *
    * @param by is a string selector
    * @param using is a value of the given selector
    * @return a list of elements
    *
    * @throws org.openqa.selenium.WebDriverException when current session doesn't support
    *       the given selector or when value of the selector is not consistent.
    */
    List<T> findElements(String by, String using);
}

==> java-client-7.1.0-sources.jar: io/appium/java_client/FindsByFluentSelector.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.appium.java_client;

import org.openqa.selenium.WebElement;

import java.util.List;

public interface FindsByFluentSelector<T extends WebElement> {

    /**
    * Method performs the searching for a single element by some selector defined by string
    * and value of the given selector.
    *
    * @param by is a string selector
    * @param using is a value of the given selector
    * @return the first found element
    *
    * @throws org.openqa.selenium.WebDriverException when current session doesn't
    *       support the given selector or when value of the selector is not consistent.
    * @throws org.openqa.selenium.NoSuchElementException when no one element is found
    */
    T findElement(String by, String using);

    /**
    * Method performs the searching for a list of elements by some selector defined by string
    * and value of the given selector.
    *
    * @param by is a string selector
    * @param using is a value of the given selector
    * @return a list of elements
    *
    * @throws org.openqa.selenium.WebDriverException when current session doesn't support
    *       the given selector or when value of the selector is not consistent.
    */
    List<T> findElements(String by, String using);
}
